#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""This module gathers all other modules (except tkinter_ui) in one
unique common namespace.

This makes it easier to refer to all existing classes through a unique
module name.

Example::

    from CoolWorld import game
    world = game.World2D()
    player = game.WorldPlayer2D(world, name="player")
    enemy = game.WorldSprite2D(world, name="enemy")
    view = game.WorldView(world, name="view")
    world.run()
"""

"""
    The MIT License (MIT)

    Copyright (c) 2015 Raphaël SEBAN

    Permission is hereby granted, free of charge, to any person
    obtaining a copy of this software and associated documentation
    files (the "Software"), to deal in the Software without
    restriction, including without limitation the rights to use, copy,
    modify, merge, publish, distribute, sublicense, and/or sell copies
    of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be
    included in all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
    EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
    NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
    BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
    ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
    CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
    SOFTWARE.
"""

try:
    from .events import *
    from .geometry import *
    from .images import *
    from .shapes import *
    from .sounds import *
    from .visual import *
    from .world import *
except:
    from events import *
    from geometry import *
    from images import *
    from shapes import *
    from sounds import *
    from visual import *
    from world import *
# end try
